==> nivo-0.6.0.tgz: package/es/components/charts/stack/StackSlicer.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import invariant from 'invariant';
import _ from 'lodash-es';
import d3 from 'd3';
import { getColorGenerator } from '../../../ColorUtils';

var overTransitionDuration = 200;
var overTransitionEasing = 'linear';

var StackSlicer = function (_Component) {
    _inherits(StackSlicer, _Component);

    function StackSlicer() {
        _classCallCheck(this, StackSlicer);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    StackSlicer.decorateStack = function decorateStack(element) {
        var props = element.props;


        var colorFn = getColorGenerator(props.color);
        var dotBorderColorFn = getColorGenerator(props.dotBorderColor);
        var lineColorFn = getColorGenerator(props.lineColor);
        var showOnOver = props.showOnOver;

        // Receive context from Parent Stack component

        return function (_ref) {
            var wrapper = _ref.wrapper,
                stacked = _ref.stacked,
                width = _ref.width,
                height = _ref.height,
                transitionDuration = _ref.transitionDuration,
                transitionEasing = _ref.transitionEasing;

            var slices = [];
            stacked.forEach(function (layer) {
                layer.values.forEach(function (datum, i) {
                    if (!slices[i]) {
                        slices[i] = {
                            x: datum.interpolated.x,
                            values: []
                        };
                    }

                    slices[i].values.push(_.assign({}, datum, {
                        index: layer.index,
                        color: layer.color
                    }));
                });
            });

            var elements = wrapper.selectAll('.nivo_stack_slices').data(slices);

            var newSlices = elements.enter().append('g').attr('class', 'nivo_stack_slices').attr('transform', function (d) {
                return 'translate(' + d.x + ',0)';
            }).style('opacity', showOnOver ? 0 : 1).style('pointer-events', 'all');

            newSlices.append('rect').attr('width', props.radius * 2 + 10).attr('height', height).attr('transform', 'translate(-' + (props.radius + 5) + ',0)').style('fill', 'none').style('pointer-events', 'all');

            elements.style('opacity', showOnOver ? 0 : 1).on('mouseover', function () {
                if (!showOnOver) {
                    return;
                }

                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).style('opacity', 1);
            }).on('mouseout', function () {
                if (!showOnOver) {
                    return;
                }

                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).style('opacity', 0);
            }).transition().duration(transitionDuration).ease(transitionEasing).attr('transform', function (d) {
                return 'translate(' + d.x + ',0)';
            });

            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            // Lines
            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            var lines = elements.selectAll('line').data(function (d) {
                return d.values;
            }, function (d) {
                return d.index;
            });

            // ENTER
            lines.enter().append('line').attr('y1', function (d) {
                return d.interpolated.y;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('stroke-width', props.lineWidth).style('stroke', lineColorFn);

            // UPDATE
            lines.transition().duration(transitionDuration).ease(transitionEasing).attr('y1', function (d) {
                return d.interpolated.y;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('stroke-width', props.lineWidth).style('stroke', lineColorFn);

            // EXIT
            lines.exit().transition().duration(transitionDuration).ease(transitionEasing).attr('y1', function (d) {
                return d.interpolated.y0;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('opacity', 0).remove();

            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            // Circles
            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            var circles = elements.selectAll('circle').data(function (d) {
                return d.values;
            }, function (d) {
                return d.index;
            });

            // ENTER
            circles.enter().append('circle').attr('r', 0.1).style('cursor', 'pointer').attr('transform', function (d) {
                return 'translate(0,' + d.interpolated.y + ')';
            }).style('fill', colorFn).style('stroke-width', props.dotBorderWidth).style('stroke', dotBorderColorFn);

            // UPDATE
            circles.on('mouseover', function () {
                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).attr('r', props.radius * 2);
            }).on('mouseout', function () {
                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).attr('r', props.radius);
            }).transition().duration(transitionDuration).ease(transitionEasing).attr('r', props.radius).attr('transform', function (d) {
                return 'translate(0,' + d.interpolated.y + ')';
            }).style('fill', colorFn).style('stroke-width', props.dotBorderWidth).style('stroke', dotBorderColorFn);

            // EXIT
            circles.exit().transition().duration(transitionDuration).ease(transitionEasing).attr('r', 0.1).style('opacity', 0).remove();
        };
    };

    StackSlicer.prototype.render = function render() {
        invariant(false, '<StackSlicer> element is for Stack configuration only and should not be rendered');
    };

    return StackSlicer;
}(Component);

var number = PropTypes.number,
    bool = PropTypes.bool,
    any = PropTypes.any;


StackSlicer.propTypes = {
    showOnOver: bool.isRequired,
    radius: number.isRequired,
    color: any.isRequired,
    dotBorderWidth: number.isRequired,
    dotBorderColor: any.isRequired,
    lineWidth: number.isRequired
};

StackSlicer.defaultProps = {
    showOnOver: false,
    radius: 4,
    color: 'inherit',
    dotBorderWidth: 1,
    dotBorderColor: 'inherit:darker(.5)',
    lineWidth: 1,
    lineColor: 'inherit:darker(.3)'
};

export default StackSlicer;

==> nivo-0.15.0.tgz: package/es/components/charts/stack/StackSlicer.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import invariant from 'invariant';
import _ from 'lodash-es';
import d3 from 'd3';
import { getColorGenerator } from '../../../lib/colorUtils';

var overTransitionDuration = 200;
var overTransitionEasing = 'linear';

var StackSlicer = function (_Component) {
    _inherits(StackSlicer, _Component);

    function StackSlicer() {
        _classCallCheck(this, StackSlicer);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    StackSlicer.decorateStack = function decorateStack(element) {
        var props = element.props;


        var colorFn = getColorGenerator(props.color);
        var dotBorderColorFn = getColorGenerator(props.dotBorderColor);
        var lineColorFn = getColorGenerator(props.lineColor);
        var showOnOver = props.showOnOver;

        // Receive context from Parent Stack component

        return function (_ref) {
            var wrapper = _ref.wrapper,
                stacked = _ref.stacked,
                width = _ref.width,
                height = _ref.height,
                transitionDuration = _ref.transitionDuration,
                transitionEasing = _ref.transitionEasing;

            var slices = [];
            stacked.forEach(function (layer) {
                layer.values.forEach(function (datum, i) {
                    if (!slices[i]) {
                        slices[i] = {
                            x: datum.interpolated.x,
                            values: []
                        };
                    }

                    slices[i].values.push(_.assign({}, datum, {
                        index: layer.index,
                        color: layer.color
                    }));
                });
            });

            var elements = wrapper.selectAll('.nivo_stack_slices').data(slices);

            var newSlices = elements.enter().append('g').attr('class', 'nivo_stack_slices').attr('transform', function (d) {
                return 'translate(' + d.x + ',0)';
            }).style('opacity', showOnOver ? 0 : 1).style('pointer-events', 'all');

            newSlices.append('rect').attr('width', props.radius * 2 + 10).attr('height', height).attr('transform', 'translate(-' + (props.radius + 5) + ',0)').style('fill', 'none').style('pointer-events', 'all');

            elements.style('opacity', showOnOver ? 0 : 1).on('mouseover', function () {
                if (!showOnOver) {
                    return;
                }

                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).style('opacity', 1);
            }).on('mouseout', function () {
                if (!showOnOver) {
                    return;
                }

                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).style('opacity', 0);
            }).transition().duration(transitionDuration).ease(transitionEasing).attr('transform', function (d) {
                return 'translate(' + d.x + ',0)';
            });

            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            // Lines
            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            var lines = elements.selectAll('line').data(function (d) {
                return d.values;
            }, function (d) {
                return d.index;
            });

            // ENTER
            lines.enter().append('line').attr('y1', function (d) {
                return d.interpolated.y;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('stroke-width', props.lineWidth).style('stroke', lineColorFn);

            // UPDATE
            lines.transition().duration(transitionDuration).ease(transitionEasing).attr('y1', function (d) {
                return d.interpolated.y;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('stroke-width', props.lineWidth).style('stroke', lineColorFn);

            // EXIT
            lines.exit().transition().duration(transitionDuration).ease(transitionEasing).attr('y1', function (d) {
                return d.interpolated.y0;
            }).attr('y2', function (d) {
                return d.interpolated.y0;
            }).style('opacity', 0).remove();

            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            // Circles
            // —————————————————————————————————————————————————————————————————————————————————————————————————————————
            var circles = elements.selectAll('circle').data(function (d) {
                return d.values;
            }, function (d) {
                return d.index;
            });

            // ENTER
            circles.enter().append('circle').attr('r', 0.1).style('cursor', 'pointer').attr('transform', function (d) {
                return 'translate(0,' + d.interpolated.y + ')';
            }).style('fill', colorFn).style('stroke-width', props.dotBorderWidth).style('stroke', dotBorderColorFn);

            // UPDATE
            circles.on('mouseover', function () {
                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).attr('r', props.radius * 2);
            }).on('mouseout', function () {
                d3.select(this).transition().duration(overTransitionDuration).ease(overTransitionEasing).attr('r', props.radius);
            }).transition().duration(transitionDuration).ease(transitionEasing).attr('r', props.radius).attr('transform', function (d) {
                return 'translate(0,' + d.interpolated.y + ')';
            }).style('fill', colorFn).style('stroke-width', props.dotBorderWidth).style('stroke', dotBorderColorFn);

            // EXIT
            circles.exit().transition().duration(transitionDuration).ease(transitionEasing).attr('r', 0.1).style('opacity', 0).remove();
        };
    };

    StackSlicer.prototype.render = function render() {
        invariant(false, '<StackSlicer> element is for Stack configuration only and should not be rendered');
    };

    return StackSlicer;
}(Component);

var number = PropTypes.number,
    bool = PropTypes.bool,
    any = PropTypes.any;


StackSlicer.propTypes = {
    showOnOver: bool.isRequired,
    radius: number.isRequired,
    color: any.isRequired,
    dotBorderWidth: number.isRequired,
    dotBorderColor: any.isRequired,
    lineWidth: number.isRequired
};

StackSlicer.defaultProps = {
    showOnOver: false,
    radius: 4,
    color: 'inherit',
    dotBorderWidth: 1,
    dotBorderColor: 'inherit:darker(.5)',
    lineWidth: 1,
    lineColor: 'inherit:darker(.3)'
};

export default StackSlicer;
